==> causeway-bom-2.1.0-source-release.zip: causeway-bom-2.1.0/testing/fixtures/applib/src/test/java/org/apache/causeway/testing/fixtures/applib/personas/fixtures/PersonBuilderScript.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 *
 */

package org.apache.causeway.testing.fixtures.applib.personas.fixtures;

import javax.inject.Inject;

import org.apache.causeway.testing.fixtures.applib.personas.BuilderScriptWithResult;
import org.apache.causeway.testing.fixtures.applib.personas.dom.Person;
import org.apache.causeway.testing.fixtures.applib.personas.dom.PersonRepository;

import lombok.RequiredArgsConstructor;


@RequiredArgsConstructor
public class PersonBuilderScript extends BuilderScriptWithResult<Person> {

    private final Person_persona persona;

    @Override
    protected Person buildResult(final ExecutionContext ec) {
        return customerRepository.create(persona.getFirstName(), persona.getLastName(), persona.getAge());
    }

    @Inject PersonRepository customerRepository;

}

==> causeway-bom-3.1.0-source-release.zip: causeway-bom-3.1.0/testing/fixtures/applib/src/test/java/org/apache/causeway/testing/fixtures/applib/personas/fixtures/PersonBuilderScript.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 *
 */

package org.apache.causeway.testing.fixtures.applib.personas.fixtures;

import jakarta.inject.Inject;

import org.apache.causeway.testing.fixtures.applib.personas.BuilderScriptWithResult;
import org.apache.causeway.testing.fixtures.applib.personas.dom.Person;
import org.apache.causeway.testing.fixtures.applib.personas.dom.PersonRepository;

import lombok.RequiredArgsConstructor;


@RequiredArgsConstructor
public class PersonBuilderScript extends BuilderScriptWithResult<Person> {

    private final Person_persona persona;

    @Override
    protected Person buildResult(final ExecutionContext ec) {
        return customerRepository.create(persona.getFirstName(), persona.getLastName(), persona.getAge());
    }

    @Inject PersonRepository customerRepository;

}
